@@ -1,13 +1,8 @@
 #!/bin/bash
-. tests/common.sh
+. tests/shlib/common.sh
 
 enter_suite root
 
-: ${USER:=`id -un`}
-: ${HOME:=`getent passwd $USER | cut -d: -f6`}
-
-export USER HOME
-
 if test "$TRAVIS" = true ; then
 	export PATH="$HOME/opt/fish/bin:${PATH}"
 	export PATH="$PWD/tests/bot-ci/deps/rc:$PATH"
@@ -22,18 +17,16 @@ if test "$TRAVIS" = true ; then
 		. virtualenvwrapper.sh
 		workon cpython-ucs2-$UCS2_PYTHON_VARIANT
 		set -e
+	else
+		LIBRARY_PATH="$(ldd "$(which python)" | grep libpython | sed 's/^.* => //;s/ .*$//')"
+		LIBRARY_DIR="$(dirname "${LIBRARY_PATH}")"
+		export LD_LIBRARY_PATH="$LIBRARY_DIR${LD_LIBRARY_PATH:+:}$LD_LIBRARY_PATH"
 	fi
 fi
 
-if ! which realpath ; then
-	realpath() {
-		$PYTHON -c 'import os, sys; print(os.path.realpath(sys.argv[1]))' "$1"
-	}
-fi
-
 export PYTHON="${PYTHON:=python}"
 export PYTHONPATH="${PYTHONPATH}${PYTHONPATH:+:}`realpath .`"
-for script in tests/run_*_tests.sh ; do
+for script in "$ROOT"/tests/test_*/test.sh ; do
 	test_name="${script##*/run_}"
 	if ! sh $script ; then
 		fail "${test_name%_tests.sh}" F "Failed $script"
