@@ -1,23 +1,18 @@
 #!/bin/sh
-. tests/common.sh
+. tests/shlib/common.sh
 
-enter_suite shells
+enter_suite shell
 
-if test "x$1" = "x--fast" ; then
+if test $# -eq 0 ; then
 	FAST=1
-	shift
 fi
 ONLY_SHELL="$1"
 ONLY_TEST_TYPE="$2"
 ONLY_TEST_CLIENT="$3"
 
-if ! test -z "$ONLY_SHELL$ONLY_TEST_TYPE$ONLY_TEST_CLIENT" ; then
-	FAST=
-fi
-
 export PYTHON
 
-if test "x$ONLY_SHELL" = "x--help" ; then
+if test "$ONLY_SHELL" = "--help" ; then
 cat << EOF
 Usage:
 	$0 [[[ONLY_SHELL | ""] (ONLY_TEST_TYPE | "")] (ONLY_TEST_CLIENT | "")]
@@ -33,14 +28,16 @@ check_screen_log() {
 	TEST_TYPE="$1"
 	TEST_CLIENT="$2"
 	SH="$3"
-	if test -e tests/test_shells/${SH}.${TEST_TYPE}.ok ; then
-		diff -a -u tests/test_shells/${SH}.${TEST_TYPE}.ok tests/shell/${SH}.${TEST_TYPE}.${TEST_CLIENT}.log
+	if test -e "$ROOT/tests/test_shells/outputs/${SH}.${TEST_TYPE}.ok" ; then
+		diff -a -u "$ROOT/tests/test_shells/outputs/${SH}.${TEST_TYPE}.ok" \
+		           "$TEST_ROOT/${SH}.${TEST_TYPE}.${TEST_CLIENT}.log"
 		return $?
-	elif test -e tests/test_shells/${SH}.ok ; then
-		diff -a -u tests/test_shells/${SH}.ok tests/shell/${SH}.${TEST_TYPE}.${TEST_CLIENT}.log
+	elif test -e "$ROOT/tests/test_shells/outputs/${SH}.ok" ; then
+		diff -a -u "$ROOT/tests/test_shells/outputs/${SH}.ok" \
+		           "$TEST_ROOT/${SH}.${TEST_TYPE}.${TEST_CLIENT}.log"
 		return $?
 	else
-		cat tests/shell/${SH}.${TEST_TYPE}.${TEST_CLIENT}.log
+		cat "$TEST_ROOT/${SH}.${TEST_TYPE}.${TEST_CLIENT}.log"
 		return 1
 	fi
 }
@@ -55,13 +52,13 @@ print_full_output() {
 	SH="$3"
 	echo "Full output:"
 	echo '============================================================'
-	cat tests/shell/${SH}.${TEST_TYPE}.${TEST_CLIENT}.full.log
+	cat "$TEST_ROOT/${SH}.${TEST_TYPE}.${TEST_CLIENT}.full.log"
 	echo
 	echo '____________________________________________________________'
-	if test "x$POWERLINE_TEST_NO_CAT_V" != "x1" ; then
+	if test "$POWERLINE_TEST_NO_CAT_V" != "1" ; then
 		echo "Full output (cat -v):"
 		echo '============================================================'
-		cat -v tests/shell/${SH}.${TEST_TYPE}.${TEST_CLIENT}.full.log
+		cat -v "$TEST_ROOT/${SH}.${TEST_TYPE}.${TEST_CLIENT}.full.log"
 		echo
 		echo '____________________________________________________________'
 	fi
@@ -76,9 +73,9 @@ do_run_test() {
 
 	local wait_for_echo_arg=
 	if ( \
-		test "x${SH}" = "xdash" \
+		test "${SH}" = "dash" \
 		|| ( \
-			test "x${SH}" = "xpdb" \
+			test "${SH}" = "pdb" \
 			&& ( \
 				( \
 					test "$PYTHON_VERSION_MAJOR" -eq 3 \
@@ -89,7 +86,7 @@ do_run_test() {
 			) \
 		) \
 		|| ( \
-			test "x${SH}" = "xipython" \
+			test "${SH}" = "ipython" \
 			&& test "$("${PYTHON}" -mIPython --version | head -n1 | cut -d. -f1)" -ge 5 \
 		) \
 	) ; then
@@ -100,7 +97,7 @@ do_run_test() {
 		"$@"
 	if ! check_screen_log ${TEST_TYPE} ${TEST_CLIENT} ${SH} ; then
 		echo '____________________________________________________________'
-		if test "x$POWERLINE_TEST_NO_CAT_V" != "x1" ; then
+		if test "$POWERLINE_TEST_NO_CAT_V" != "1" ; then
 			# Repeat the diff to make it better viewable in travis output
 			echo "Diff (cat -v):"
 			echo '============================================================'
@@ -109,9 +106,9 @@ do_run_test() {
 		fi
 		echo -n "Failed ${SH}. "
 		print_full_output ${TEST_TYPE} ${TEST_CLIENT} ${SH}
-		case ${SH} in
+		case "${SH}" in
 			*ksh)
-				${SH} -c 'echo ${KSH_VERSION}'
+				"$TEST_ROOT/path/${SH}" -c 'echo ${KSH_VERSION}'
 				;;
 			dash)
 				# ?
@@ -120,7 +117,7 @@ do_run_test() {
 				busybox --help
 				;;
 			*)
-				${SH} --version
+				"$TEST_ROOT/path/${SH}" --version
 				;;
 		esac
 		if which dpkg >/dev/null ; then
@@ -140,82 +137,82 @@ run_test() {
 		attempts=1
 	fi
 	while test $attempts -gt 0 ; do
-		rm -f tests/shell/${SH}.${TEST_TYPE}.${TEST_CLIENT}.log
-		rm -f tests/shell/${SH}.${TEST_TYPE}.${TEST_CLIENT}.full.log
+		rm -f "$TEST_ROOT/${SH}.${TEST_TYPE}.${TEST_CLIENT}.log"
+		rm -f "$TEST_ROOT/${SH}.${TEST_TYPE}.${TEST_CLIENT}.full.log"
 		do_run_test "$@" && return 0
 		attempts=$(( attempts - 1 ))
 	done
 	return 1
 }
 
-test -d tests/shell && rm -r tests/shell
-mkdir tests/shell
-git init tests/shell/3rd
-git --git-dir=tests/shell/3rd/.git checkout -b BRANCH
+make_test_root
+
+git init "$TEST_ROOT/3rd"
+git --git-dir="$TEST_ROOT/3rd/.git" checkout -b BRANCH
 export DIR1="[32m"
 export DIR2=""
-mkdir tests/shell/3rd/"$DIR1"
-mkdir tests/shell/3rd/"$DIR2"
-mkdir tests/shell/3rd/'\[\]'
-mkdir tests/shell/3rd/'%%'
-mkdir tests/shell/3rd/'#[bold]'
-mkdir tests/shell/3rd/'(echo)'
-mkdir tests/shell/3rd/'$(echo)'
-mkdir tests/shell/3rd/'`echo`'
-mkdir tests/shell/3rd/'«Unicode!»'
+mkdir "$TEST_ROOT/3rd/$DIR1"
+mkdir "$TEST_ROOT/3rd/$DIR2"
+mkdir "$TEST_ROOT"/3rd/'\[\]'
+mkdir "$TEST_ROOT"/3rd/'%%'
+mkdir "$TEST_ROOT"/3rd/'#[bold]'
+mkdir "$TEST_ROOT"/3rd/'(echo)'
+mkdir "$TEST_ROOT"/3rd/'$(echo)'
+mkdir "$TEST_ROOT"/3rd/'`echo`'
+mkdir "$TEST_ROOT"/3rd/'«Unicode!»'
 
-mkdir tests/shell/fish_home
-mkdir tests/shell/fish_home/fish
-mkdir tests/shell/fish_home/fish/generated_completions
-cp -r tests/test_shells/ipython_home tests/shell
+mkdir "$TEST_ROOT/fish_home"
+mkdir "$TEST_ROOT/fish_home/fish"
+mkdir "$TEST_ROOT/fish_home/fish/generated_completions"
+cp -r "$ROOT/tests/test_shells/ipython_home" "$TEST_ROOT"
 
-mkdir tests/shell/path
-ln -s "$(which "${PYTHON}")" tests/shell/path/python
-ln -s "$(which env)" tests/shell/path
-ln -s "$(which git)" tests/shell/path
-ln -s "$(which sleep)" tests/shell/path
-ln -s "$(which cat)" tests/shell/path
-ln -s "$(which false)" tests/shell/path
-ln -s "$(which true)" tests/shell/path
-ln -s "$(which kill)" tests/shell/path
-ln -s "$(which echo)" tests/shell/path
-ln -s "$(which which)" tests/shell/path
-ln -s "$(which dirname)" tests/shell/path
-ln -s "$(which wc)" tests/shell/path
-ln -s "$(which stty)" tests/shell/path
-ln -s "$(which cut)" tests/shell/path
-ln -s "$(which bc)" tests/shell/path
-ln -s "$(which expr)" tests/shell/path
-ln -s "$(which mktemp)" tests/shell/path
-ln -s "$(which grep)" tests/shell/path
-ln -s "$(which sed)" tests/shell/path
-ln -s "$(which rm)" tests/shell/path
-ln -s "$(which tr)" tests/shell/path
-ln -s "$(which uname)" tests/shell/path
-ln -s "$(which test)" tests/shell/path
-ln -s "$(which pwd)" tests/shell/path
-ln -s "$(which hostname)" tests/shell/path
-ln -s ../../test_shells/bgscript.sh tests/shell/path
-ln -s ../../test_shells/waitpid.sh tests/shell/path
+mkdir "$TEST_ROOT/path"
+ln -s "$(which "${PYTHON}")" "$TEST_ROOT/path/python"
+ln -s "$(which env)" "$TEST_ROOT/path"
+ln -s "$(which git)" "$TEST_ROOT/path"
+ln -s "$(which sleep)" "$TEST_ROOT/path"
+ln -s "$(which cat)" "$TEST_ROOT/path"
+ln -s "$(which false)" "$TEST_ROOT/path"
+ln -s "$(which true)" "$TEST_ROOT/path"
+ln -s "$(which kill)" "$TEST_ROOT/path"
+ln -s "$(which echo)" "$TEST_ROOT/path"
+ln -s "$(which which)" "$TEST_ROOT/path"
+ln -s "$(which dirname)" "$TEST_ROOT/path"
+ln -s "$(which wc)" "$TEST_ROOT/path"
+ln -s "$(which stty)" "$TEST_ROOT/path"
+ln -s "$(which cut)" "$TEST_ROOT/path"
+ln -s "$(which bc)" "$TEST_ROOT/path"
+ln -s "$(which expr)" "$TEST_ROOT/path"
+ln -s "$(which mktemp)" "$TEST_ROOT/path"
+ln -s "$(which grep)" "$TEST_ROOT/path"
+ln -s "$(which sed)" "$TEST_ROOT/path"
+ln -s "$(which rm)" "$TEST_ROOT/path"
+ln -s "$(which tr)" "$TEST_ROOT/path"
+ln -s "$(which uname)" "$TEST_ROOT/path"
+ln -s "$(which test)" "$TEST_ROOT/path"
+ln -s "$(which pwd)" "$TEST_ROOT/path"
+ln -s "$(which hostname)" "$TEST_ROOT/path"
+ln -s "$ROOT/tests/test_shells/bgscript.sh" "$TEST_ROOT/path"
+ln -s "$ROOT/tests/test_shells/waitpid.sh" "$TEST_ROOT/path"
 if which socat ; then
-	ln -s "$(which socat)" tests/shell/path
+	ln -s "$(which socat)" "$TEST_ROOT/path"
 fi
 for pexe in powerline powerline-config powerline-render powerline.sh powerline.py ; do
-	if test -e scripts/$pexe ; then
-		ln -s "$PWD/scripts/$pexe" tests/shell/path
+	if test -e "$ROOT/scripts/$pexe" ; then
+		ln -s "$ROOT/scripts/$pexe" "$TEST_ROOT/path"
 	elif test -e client/$pexe ; then
-		ln -s "$PWD/client/$pexe" tests/shell/path
+		ln -s "$ROOT/client/$pexe" "$TEST_ROOT/path"
 	elif which $pexe ; then
-		ln -s "$(which $pexe)" tests/shell/path
+		ln -s "$(which $pexe)" "$TEST_ROOT/path"
 	else
 		echo "Executable $pexe was not found"
 		exit 1
 	fi
 done
 
-ln -s python tests/shell/path/pdb
+ln -s python "$TEST_ROOT/path/pdb"
 PDB_PYTHON=pdb
-ln -s python tests/shell/path/ipython
+ln -s python "$TEST_ROOT/path/ipython"
 IPYTHON_PYTHON=ipython
 
 if test -z "$POWERLINE_RC_EXE" ; then
@@ -229,10 +226,20 @@ if test -z "$POWERLINE_RC_EXE" ; then
 fi
 
 if which "$POWERLINE_RC_EXE" >/dev/null ; then
-	ln -s "$(which $POWERLINE_RC_EXE)" tests/shell/path/rc
+	ln -s "$(which $POWERLINE_RC_EXE)" "$TEST_ROOT/path/rc"
 fi
 
-for exe in bash zsh busybox fish tcsh mksh dash ; do
+exes="bash zsh busybox tcsh mksh"
+
+if test "$TRAVIS" != "true" ; then
+	# For some reason fish does not work on travis
+	exes="$exes fish"
+fi
+
+# dash has some problems with job control
+#exes="$exes dash"
+
+for exe in $exes ; do
 	if which $exe >/dev/null ; then
 		if test "$exe" = "fish" ; then
 			fish_version="$(fish --version 2>&1)"
@@ -261,12 +268,12 @@ for exe in bash zsh busybox fish tcsh mksh dash ; do
 				fi
 			fi
 		fi
-		ln -s "$(which $exe)" tests/shell/path
+		ln -s "$(which $exe)" "$TEST_ROOT/path"
 	fi
 done
 
-mkdir tests/shell/home
-export HOME="$PWD/tests/shell/home"
+mkdir "$TEST_ROOT/home"
+export HOME="$TEST_ROOT/home"
 
 unset ENV
 
@@ -277,7 +284,10 @@ echo "Powerline address: $ADDRESS"
 check_test_client() {
 	local executable="$1"
 	local client_type="$2"
-	local actual_mime_type="$(file --mime-type --brief --dereference "tests/shell/path/$executable" | cut -d/ -f1)"
+	local actual_mime_type="$(
+		file --mime-type --brief --dereference "$TEST_ROOT/path/$executable" \
+		| cut -d/ -f1
+	)"
 	local expected_mime_type
 	case "$client_type" in
 		C)      expected_mime_type="application/x-executable" ;;
@@ -291,14 +301,20 @@ check_test_client() {
 	fi
 }
 
-if test -z "${ONLY_SHELL}" || test "x${ONLY_SHELL%sh}" != "x${ONLY_SHELL}" || test "x${ONLY_SHELL}" = xbusybox || test "x${ONLY_SHELL}" = xrc ; then
+if ( \
+	test -z "${ONLY_SHELL}" \
+	|| test "${ONLY_SHELL%sh}" != "${ONLY_SHELL}" \
+	|| test "${ONLY_SHELL}" = "busybox" \
+	|| test "${ONLY_SHELL}" = "rc" \
+) ; then
 	scripts/powerline-config shell command
 
 	for TEST_TYPE in "daemon" "nodaemon" ; do
-		if test "x$ONLY_TEST_TYPE" != "x" && test "x$ONLY_TEST_TYPE" != "x$TEST_TYPE" ; then
+		if test -n "$ONLY_TEST_TYPE" && test "$ONLY_TEST_TYPE" != "$TEST_TYPE"
+		then
 			continue
 		fi
-		if test x$FAST = x1 ; then
+		if test "$FAST" = 1 ; then
 			if test $TEST_TYPE = daemon ; then
 				VARIANTS=3
 			else
@@ -310,8 +326,8 @@ if test -z "${ONLY_SHELL}" || test "x${ONLY_SHELL%sh}" != "x${ONLY_SHELL}" || te
 
 		if test $TEST_TYPE = daemon ; then
 			sh -c '
-				echo $$ > tests/shell/daemon_pid
-				$PYTHON ./scripts/powerline-daemon -s$ADDRESS -f >tests/shell/daemon_log 2>&1
+				echo $$ > "$TEST_ROOT/daemon_pid"
+				exec "$PYTHON" ./scripts/powerline-daemon -s"$ADDRESS" -f >"$TEST_ROOT/daemon_log" 2>&1
 			' &
 		fi
 		echo "> Testing $TEST_TYPE"
@@ -333,17 +349,24 @@ if test -z "${ONLY_SHELL}" || test "x${ONLY_SHELL%sh}" != "x${ONLY_SHELL}" || te
 				continue
 			fi
 			I="$(( I + 1 ))"
-			if test "$TEST_CLIENT" = "C" && ! test -x scripts/powerline ; then
+			if test "$TEST_CLIENT" = "C" && ! test -x "$ROOT/scripts/powerline"
+			then
 				if which powerline >/dev/null ; then
 					POWERLINE_COMMAND=powerline
 				else
 					continue
 				fi
 			fi
-			if test "$TEST_CLIENT" = "shell" && ! test -x tests/shell/path/socat ; then
+			if ( \
+				test "$TEST_CLIENT" = "shell" \
+				&& ! test -x "$TEST_ROOT/path/socat" \
+			) ; then
 				continue
 			fi
-			if test "x$ONLY_TEST_CLIENT" != "x" && test "x$TEST_CLIENT" != "x$ONLY_TEST_CLIENT" ; then
+			if ( \
+				test -n "$ONLY_TEST_CLIENT" \
+				&& test "$TEST_CLIENT" != "$ONLY_TEST_CLIENT" \
+			) ; then
 				continue
 			fi
 			export POWERLINE_COMMAND_ARGS="--socket $ADDRESS"
@@ -361,90 +384,96 @@ if test -z "${ONLY_SHELL}" || test "x${ONLY_SHELL%sh}" != "x${ONLY_SHELL}" || te
 				"rc -i -p"
 			do
 				J="$(( J + 1 ))"
-				if test x$FAST = x1 ; then
+				if test "$FAST" = 1 ; then
 					if test $(( (I + J) % $VARIANTS )) -ne $EXETEST ; then
 						continue
 					fi
 				fi
 				SH="${TEST_COMMAND%% *}"
-				if test "x$ONLY_SHELL" != "x" && test "x$ONLY_SHELL" != "x$SH" ; then
+				if test -n "$ONLY_SHELL" && test "$ONLY_SHELL" != "$SH" ; then
 					continue
 				fi
-				if ! test -x tests/shell/path/$SH ; then
+				if ! test -x "$TEST_ROOT/path/$SH" ; then
 					continue
 				fi
-				echo ">>> $(readlink "tests/shell/path/$SH")"
+				echo ">>> $(readlink "$TEST_ROOT/path/$SH")"
 				if ! run_test $TEST_TYPE $TEST_CLIENT $TEST_COMMAND ; then
-					ALLOW_FAILURE_ARG=
-					# dash tests are not stable, see #931
-					# also do not allow fish tests to spoil the build
-					if test x$FAST$SH = x1dash || test x$FAST$SH = x1fish ; then
-						ALLOW_FAILURE_ARG="--allow-failure"
-					fi
-					fail $ALLOW_FAILURE_ARG "$SH-$TEST_TYPE-$TEST_CLIENT:test" F "Failed checking $TEST_COMMAND"
+					fail "$SH-$TEST_TYPE-$TEST_CLIENT:test" F \
+						"Failed checking $TEST_COMMAND"
 				fi
 			done
 		done
 		if test $TEST_TYPE = daemon ; then
-			$PYTHON ./scripts/powerline-daemon -s$ADDRESS -k
-			wait $(cat tests/shell/daemon_pid)
-			if ! test -z "$(cat tests/shell/daemon_log)" ; then
+			"$PYTHON" ./scripts/powerline-daemon -s"$ADDRESS" -k
+			wait $(cat "$TEST_ROOT/daemon_pid")
+			if ! test -z "$(cat "$TEST_ROOT/daemon_log")" ; then
 				echo '____________________________________________________________'
 				echo "Daemon log:"
 				echo '============================================================'
-				cat tests/shell/daemon_log
-				fail "$SH-$TEST_TYPE-$TEST_CLIENT:log" E "Non-empty daemon log for ${TEST_COMMAND}"
+				cat "$TEST_ROOT/daemon_log"
+				fail "$SH-$TEST_TYPE-$TEST_CLIENT:log" E \
+					"Non-empty daemon log for ${TEST_COMMAND}"
 			fi
 		fi
 	done
 fi
 
-if $PYTHON scripts/powerline-daemon -s$ADDRESS > tests/shell/daemon_log_2 2>&1 ; then
+if "$PYTHON" scripts/powerline-daemon -s"$ADDRESS" \
+	> "$TEST_ROOT/daemon_log_2" 2>&1
+then
 	sleep 1
-	$PYTHON scripts/powerline-daemon -s$ADDRESS -k
+	"$PYTHON" scripts/powerline-daemon -s"$ADDRESS" -k
 else
 	fail "daemon:run" F "Daemon exited with status $?"
 fi
 
-if ! test -z "$(cat tests/shell/daemon_log_2)" ; then
+if ! test -z "$(cat "$TEST_ROOT/daemon_log_2")" ; then
 	echo '____________________________________________________________'
 	echo "Daemon log (2nd):"
 	echo '============================================================'
-	cat tests/shell/daemon_log_2
+	cat "$TEST_ROOT/daemon_log_2"
 	fail "daemon:log" E "Daemon run with non-empty log"
 fi
 
-if ( test "x${ONLY_SHELL}" = "x" || test "x${ONLY_SHELL}" = "xzsh" ) \
-	&& ( test "x${ONLY_TEST_TYPE}" = "x" || test "x${ONLY_TEST_TYPE}" = "xzpython" ) \
-	&& zsh tests/test_shells/zsh_test_script.zsh 2>/dev/null; then
+if ( test -z "${ONLY_SHELL}" || test "${ONLY_SHELL}" = "zsh" ) \
+	&& ( test -z "${ONLY_TEST_TYPE}" || test "${ONLY_TEST_TYPE}" = "zpython" ) \
+	&& "$TEST_ROOT/path/zsh" "$ROOT/tests/test_shells/zsh_test_script.zsh"
+then
 	echo "> zpython"
 	if ! run_test zpython zpython zsh -f -i ; then
 		fail "zsh-zpython:test" F "Failed checking zsh -f -i"
 	fi
 fi
 
-if  test "x${ONLY_SHELL}" = "x" || test "x${ONLY_SHELL}" = "xpdb" ; then
+if  test -z "${ONLY_SHELL}" || test "${ONLY_SHELL}" = "pdb" ; then
 	if test "$PYTHON_IMPLEMENTATION" != "PyPy" ; then
-		if test "x${ONLY_TEST_TYPE}" = "x" || test "x${ONLY_TEST_TYPE}" = "xsubclass" ; then
+		if test -z "${ONLY_TEST_TYPE}" || test "${ONLY_TEST_TYPE}" = "subclass"
+		then
 			echo "> pdb subclass"
-			if ! run_test subclass python $PDB_PYTHON "$PWD/tests/test_shells/pdb-main.py" ; then
-				fail "pdb-subclass:test" F "Failed checking $PDB_PYTHON $PWD/tests/test_shells/pdb-main.py"
+			if ! run_test subclass python $PDB_PYTHON \
+				"$ROOT/tests/test_shells/pdb-main.py"
+			then
+				fail "pdb-subclass:test" F \
+					"Failed checking $PDB_PYTHON $ROOT/tests/test_shells/pdb-main.py"
 			fi
 		fi
-		if test "x${ONLY_TEST_TYPE}" = "x" || test "x${ONLY_TEST_TYPE}" = "xmodule" ; then
+		if test -z "${ONLY_TEST_TYPE}" || test "${ONLY_TEST_TYPE}" = "module" ; then
 			echo "> pdb module"
 			MODULE="powerline.bindings.pdb"
 			if test "$PYTHON_MM" = "2.6" ; then
 				MODULE="powerline.bindings.pdb.__main__"
 			fi
-			if ! run_test module python $PDB_PYTHON -m$MODULE "$PWD/tests/test_shells/pdb-script.py" ; then
-				fail "pdb-module:test" F "Failed checking $PDB_PYTHON -m$MODULE $PWD/tests/test_shells/pdb-script"
+			if ! run_test module python "$PDB_PYTHON" -m"$MODULE" \
+				"$ROOT/tests/test_shells/pdb-script.py"
+			then
+				fail "pdb-module:test" F \
+					"Failed checking $PDB_PYTHON -m$MODULE $ROOT/tests/test_shells/pdb-script"
 			fi
 		fi
 	fi
 fi
 
-if test "x${ONLY_SHELL}" = "x" || test "x${ONLY_SHELL}" = "xipython" ; then
+if test -z "${ONLY_SHELL}" || test "${ONLY_SHELL}" = "ipython" ; then
 	if "${PYTHON}" -c "try: import IPython${NL}except ImportError: raise SystemExit(1)" ; then
 		# Define some overrides which should be ignored by IPython.
 		export POWERLINE_CONFIG_OVERRIDES='common.term_escape_style=fbterm'
@@ -459,8 +488,4 @@ if test "x${ONLY_SHELL}" = "x" || test "x${ONLY_SHELL}" = "xipython" ; then
 	fi
 fi
 
-if test $FAILED -eq 0 ; then
-	rm -r tests/shell
-fi
-
 exit_suite
